"""Flutter MCP Server - Real-time Flutter/Dart documentation for AI assistants."""

__version__ = "0.1.0"
__author__ = "Flutter MCP Team"
__email__ = "contact@fluttermcp.dev"

from .server import mcp, main

__all__ = ["mcp", "main"]